==> haskell-summoner-tui-2.0.1.1-746-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-ABwsmJeNxvZJlhwdF4b8gc
key:                  summoner-tui-2.0.1.1-ABwsmJeNxvZJlhwdF4b8gc
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  82ae3bca1f39610a5b2f58d0a104e62b
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-ABwsmJeNxvZJlhwdF4b8gc
depends:
    base-4.18.2.1 relude-1.2.2.2-7qT18kq49d2LGqxiZMo0rc
    brick-0.71.1-CEhfNxMyW67CuEzwkwjc5
    colourista-0.1.0.2-CcCiTiMCEbxG1EtqBWcYSE directory-1.3.8.5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw
    summoner-2.0.1.1-Apslc34y1xbALjcyTliaLn
    validation-selective-0.2.0.0-FXSBl0yIg6vJRB1BPPmBxC
    vty-5.39-2aS3DEipLbxLwskKLcjGl1

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-tui-2.0.1.1-747-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-B0nalw371ny8o67ANcePW2
key:                  summoner-tui-2.0.1.1-B0nalw371ny8o67ANcePW2
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  a77ac6618386925b1e2eef2f9fce2fc5
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-B0nalw371ny8o67ANcePW2
depends:
    base-4.18.2.1 relude-1.2.2.2-EVD9l6JqgJHA3efxUTGASV
    brick-0.71.1-9w6H8dz0mgJAWgKHoLSj5u
    colourista-0.1.0.2-8BJPdA5fbg7WSI9wsWXwu directory-1.3.8.5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw
    summoner-2.0.1.1-D95DbE3LHoX416giCUiwoO
    validation-selective-0.2.0.0-45o5bKxBe9LFq26x8elKZx
    vty-5.39-2zBdP0pMKI7JSRlSqb2dwo

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
